Utils
=====

Utility functions for integration with other software,
and for the analysis of waveforms detected by cross-correlation.

.. toctree::
   :maxdepth: 1

   submodules/utils.archive_read
   submodules/utils.catalog_to_dd
   submodules/utils.catalog_utils
   submodules/utils.clustering
   submodules/utils.correlate
   submodules/utils.despike
   submodules/utils.findpeaks
   submodules/utils.mag_calc
   submodules/utils.picker
   submodules/utils.plotting
   submodules/utils.pre_processing
   submodules/utils.sac_util
   submodules/utils.stacking
   submodules/utils.synth_seis
   submodules/utils.trigger
